set echo on
set lines 100

spool remove_histogram.lst

create or replace procedure remove_histogram (
  p_table_name  varchar2,
  p_column_name varchar2
)
is
  l_distcnt    number;
  l_density    number;
  l_nullcnt    number;
  l_srec       dbms_stats.statrec;
  l_srec_empty dbms_stats.statrec;
  l_avgclen    number;
begin
  -- get the current column statistics
  dbms_stats.get_column_stats (
    ownname => user,
    tabname => p_table_name,
    colname => p_column_name,
    distcnt => l_distcnt,
    density => l_density,
    nullcnt => l_nullcnt,
    srec    => l_srec,
    avgclen => l_avgclen
  );

  -- reset them, overwriting "density"
  dbms_stats.set_column_stats (
    ownname => user,
    tabname => p_table_name,
    colname => p_column_name,
    distcnt => l_distcnt,
    density => null, -- this sets density = 1/num_distinct
    nullcnt => l_nullcnt,
    srec    => l_srec_empty,
    avgclen => l_avgclen,
    no_invalidate => false
  );

end remove_histogram;
/
show errors;

drop table test;
create table test as select mod(rownum-1,10) x from dual connect by level <= 23 union all select null from dual;
exec dbms_stats.gather_table_stats (user, 'test', method_opt=>'for all columns size 3', estimate_percent=>100);
select num_buckets, density, 1/num_distinct, low_value, high_value, num_nulls from user_tab_columns where table_name = 'TEST';
select count(*) from user_histograms where table_name = 'TEST'; 
exec remove_histogram ('test', 'x');
select num_buckets, density, 1/num_distinct, low_value, high_value, num_nulls from user_tab_columns where table_name = 'TEST';
select count(*) from user_histograms where table_name = 'TEST'; 

spool off